// Import msal_js
import 'package:msal_js/msal_js.dart';

/// Handle the Office single sign on
class OfficeSingleSignOn{

  /// The office client id
  final String officeClientId;

  /// The office scopes to get users info
  final List<String> scopes;

  final String authority;

  final String redirectUri;

  OfficeSingleSignOn({required this.officeClientId, required this.scopes, required this.authority, required this.redirectUri});

  /// Init the client application to retrieve the info
  PublicClientApplication init(){
    return PublicClientApplication(Configuration()
      ..auth = (BrowserAuthOptions()
      // Give MSAL our client ID
        ..clientId = this.officeClientId
          ..authority = this.authority
          ..redirectUri = this.redirectUri

      )
      ..cache = (CacheOptions()
      // Use local storage so logins persist across browser sessions
        ..cacheLocation = BrowserCacheLocation.localStorage)
      ..system = (BrowserSystemOptions()
        ..loggerOptions = (LoggerOptions()
        // Log just about everything for this example
          ..logLevel = LogLevel.verbose
          ..loggerCallback = _onLog)));
  }

  void _onLog(LogLevel level, String message, bool containsPii) {
    if (containsPii) {
      return;
    }

    // MSAL log message
    print('MSAL: [$level] $message');
  }

  /// Login function to retrieve user info asking permissions with a popup
  Future<String?> login() async {
    PublicClientApplication publicClientApplication = this.init();
    final loginRequest = RedirectRequest()..scopes = this.scopes;
    publicClientApplication.loginRedirect(loginRequest);
    try {
      final loginRequest = PopupRequest()..scopes = this.scopes;
      final AuthenticationResult result = await publicClientApplication.loginPopup(loginRequest);
      return result.accessToken;
    } on AuthException catch (ex) {
      return null;
    }
  }


}